@@ -25,13 +25,13 @@ KO_CODE = "ko"
 NL_CODE = "nl"
 SW_CODE = "sw"
 UK_CODE = "uk"
+CV_CODE = "cv"
 
 XX_CODE = "xx"
 
 LANGUAGES = {
     RU_CODE: {"name": "Russian"},
     ZH_CODE: {"name": "Chinese"},
-    
     DE_CODE: {"name": "German"},
     EN_CODE: {"name": "English"},
     FR_CODE: {"name": "French"},
@@ -48,6 +48,7 @@ LANGUAGES = {
     SW_CODE: {"name": "Sweden"},
     NL_CODE: {"name": "Dutch"},
     UK_CODE: {"name": "Ukrainian"},
+    CV_CODE: {"name": "Chuvash"},
 
     XX_CODE: {"name": "Unknown"}
 }
